@@ -45,7 +45,7 @@
 //! [`assert_markdown_deps_updated`]: macro.assert_markdown_deps_updated.html
 //! [`assert_html_root_url_updated`]: macro.assert_html_root_url_updated.html
 
-#![doc(html_root_url = "https://docs.rs/version-sync/0.4.0")]
+#![doc(html_root_url = "https://docs.rs/version-sync/0.5.0")]
 #![deny(missing_docs)]
 
 extern crate itertools;
@@ -338,17 +338,17 @@ fn url_matches(value: &str, pkg_name: &str, version: &Version) -> Result<()> {
     let url = Url::parse(value)
         .map_err(|err| format!("parse error: {}", err))?;
 
+    // We can only reason about docs.rs.
+    if url.domain().is_some() && url.domain() != Some("docs.rs") {
+        return Ok(());
+    }
+
     // Since docs.rs redirects HTTP traffic to HTTPS, we will ensure
     // that the scheme is "https" here.
     if url.scheme() != "https" {
         return Err(format!("expected \"https\", found {:?}", url.scheme()));
     }
 
-    // We can only reason about docs.rs.
-    if url.domain() != Some("docs.rs") {
-        return Ok(());
-    }
-
     let mut path_segments = url.path_segments()
         .ok_or_else(|| String::from("no path in URL"))?;
 
@@ -398,10 +398,8 @@ pub fn check_html_root_url(path: &str, pkg_name: &str, pkg_version: &str) -> Res
         .map_err(|err| format!("could not read {}: {}", path, err))?;
     let version = parse_version(pkg_version)
         .map_err(|err| format!("bad package version {:?}: {}", pkg_version, err))?;
-
-    let krate =
-        syn::parse_crate(&code)
-            .map_err(|source| format!("could not parse {} with source:\n{}", path, source))?;
+    let krate = syn::parse_crate(&code)
+        .map_err(|_| format!("could not parse {}: please run \"cargo build\"", path))?;
 
     println!("Checking doc attributes in {}...", path);
     for attr in krate.attrs {
@@ -441,16 +439,25 @@ pub fn check_html_root_url(path: &str, pkg_name: &str, pkg_version: &str) -> Res
                 _ => continue,
             };
 
+            // FIXME: use line number from the syn crate when it
+            // preserves span information. Here we simply find the
+            // first source line that contains "html_root_url".
+            //
+            // We know such a line must exist since we would have
+            // continue the loop above if it wasn't present.
+            let (line_no, source_line) = code.lines()
+                .enumerate()
+                .find(|&(_, line)| line.contains("html_root_url"))
+                .expect("html_root_url attribute not present");
+
             match check_result {
                 Ok(()) => {
-                    // FIXME: re-add line numbers and position in line
-                    // when the syn crate have enough capabilities to
-                    // do so.
-                    println!("{} ... ok", path);
+                    println!("{} (line {}) ... ok", path, line_no + 1);
                     return Ok(());
                 }
                 Err(err) => {
-                    println!("{} ... {}", path, err);
+                    println!("{} (line {}) ... {} in", path, line_no + 1, err);
+                    println!("{}\n", indent(source_line));
                     return Err(format!("html_root_url errors in {}", path));
                 }
             }
@@ -757,6 +764,13 @@ mod tests {
             assert_eq!(url_matches("https://example.net/foo/", "bar", &ver), Ok(()));
         }
 
+        #[test]
+        fn different_domain_http() {
+            let ver = parse_version("1.2.3").unwrap();
+            assert_eq!(url_matches("http://example.net/foo/1.2.3", "foo", &ver),
+                       Ok(()));
+        }
+
         #[test]
         fn http_url() {
             let ver = parse_version("1.2.3").unwrap();
